==> onewirelibrary-0.1-src.tar.gz: onewirelibrary-0.1/onewirelibrary/OneWire++/deviceOW++/LOW_deviceFactory.cpp <==
/***************************************************************************
                          LOW_deviceFactory.cpp  -  description
                             -------------------
    begin                : Mon Aug 5 2002
    copyright            : (C) 2002 by Harald Roelle, Helmut Reiser
    email                : roelle@informatik.uni-muenchen.de, reiser@informatik.uni-muenchen.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include "LOW_deviceFactory.h"



//=====================================================================================
//
// static methods
//

LOW_device* LOW_deviceFactory::new_SpecificDevice( LOW_netSegment &inSegment, const LOW_deviceID &inDevID)
{
  ctorFktMap_t::iterator foundCnstr = deviceCtorsSingleton->find( inDevID.getFamilyCode());
  
  if ( foundCnstr == deviceCtorsSingleton->end() )
    throw deviceFactory_error( "Family type unknown. Family code: "+inDevID.getFamilyCode(), __FILE__, __LINE__);
  
  return foundCnstr->second( inSegment, inDevID);
}


void LOW_deviceFactory::registerSpecificCtor( LOW_deviceIDRaw::devFamCode_t inFamCode, newInstanceFkt_t inPseudoCnstr)
{
  // singleton design pattern
  if ( deviceCtorsSingleton == 0 )
    deviceCtorsSingleton = new ctorFktMap_t();

  if ( inFamCode == LOW_device::anyDev_famCode )
    throw deviceFactory_error( "Cannot register for anyDev_famCode.", __FILE__, __LINE__);  

  if ( (*deviceCtorsSingleton)[inFamCode] != 0 )
    throw deviceFactory_error( "Familiy type already registered. Family code: "+
                               inFamCode, __FILE__, __LINE__);
                    
  (*deviceCtorsSingleton)[inFamCode] = inPseudoCnstr;
}



//=====================================================================================
//
// static attributes
//

// Do not really initialize here! Must use singleton pattern!
LOW_deviceFactory::ctorFktMap_t*  LOW_deviceFactory::deviceCtorsSingleton = 0;

==> onewirelibrary-0.4-src.tar.gz: onewirelibrary-0.4/onewirelibrary/OneWire++/deviceOW++/LOW_deviceFactory.cpp <==
/***************************************************************************
                          LOW_deviceFactory.cpp  -  description
                             -------------------
    begin                : Mon Aug 5 2002
    copyright            : (C) 2002 by Harald Roelle
    email                : roelle@informatik.uni-muenchen.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include "LOW_deviceFactory.h"



//=====================================================================================
//
// constructors
//

LOW_deviceFactory::LOW_deviceFactory()
{
}


LOW_deviceFactory::~LOW_deviceFactory()
{
}


//=====================================================================================
//
// static methods
//

LOW_device* LOW_deviceFactory::new_SpecificDevice( LOW_netSegment &inSegment, const LOW_deviceID &inDevID)
{
  ctorFktMap_t::iterator foundCnstr = deviceCtorsSingleton->find( inDevID.getFamilyCode());
  
  if ( foundCnstr == deviceCtorsSingleton->end() )
    throw deviceFactory_error( "Family type unknown. Family code: "+inDevID.getFamilyCode(), __FILE__, __LINE__);
  
  return foundCnstr->second( inSegment, inDevID);
}


void LOW_deviceFactory::registerSpecificCtor( LOW_deviceIDRaw::devFamCode_t inFamCode, newInstanceFkt_t inPseudoCnstr)
{
  // singleton design pattern
  if ( deviceCtorsSingleton == 0 )
    deviceCtorsSingleton = new ctorFktMap_t();

  if ( inFamCode == LOW_device::anyDev_famCode )
    throw deviceFactory_error( "Cannot register for anyDev_famCode.", __FILE__, __LINE__);  

  if ( (*deviceCtorsSingleton)[inFamCode] != 0 )
    throw deviceFactory_error( "Familiy type already registered. Family code: "+
                               inFamCode, __FILE__, __LINE__);
                    
  (*deviceCtorsSingleton)[inFamCode] = inPseudoCnstr;
}



//=====================================================================================
//
// static attributes
//

// Do not really initialize here! Must use singleton pattern!
LOW_deviceFactory::ctorFktMap_t*  LOW_deviceFactory::deviceCtorsSingleton = 0;
